@@ -286,3 +286,12 @@ class TestPullFile(helper.UnitHelper):
         self.session.get.assert_called_once_with(
             self.example_data['contents_url']
         )
+
+
+class TestPullFilePatch(TestPullFile):
+    """Unit tests for the PullFile class with empty patch."""
+
+    get_pull_file_patch_example_data = helper.create_example_data_helper(
+        'pull_file_missing_patch_example'
+    )
+    example_data = get_pull_file_patch_example_data()
